<?php

namespace App\Http\Controllers\Auth;

use App\KelasTesis;
use App\User;
use App\Manajer;
use App\Dosen;
use App\Mahasiswa;
use App\Imports\MahasiswasImport;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;
use Maatwebsite\Excel\Validators\Failure;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {

    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => 'required|string|max:255',
            'username' => 'required|string|max:4',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|min:6|confirmed',
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        return User::create([
            'name' => $data['name'],
            'username' => $data['username'],
            'email' => $data['email'],
            'phone' => $data['phone'],
            'password' => Hash::make($data['password']),
        ]);
    }


    public function showForm() {
        if(Auth::user() && Auth::user()->isManajer()) {
            return view('auth.register');
        } else {
            return abort(403);
        }
    }

    public function registerUser(Request $request) {
        $data = $request->all();
       
        $username = $data['username'];

        // validate error
        if ($data['role'] == User::ROLE_MAHASISWA) {
            $result = KelasTesis::select('*')->get();
            if ($result->isEmpty()) {
                echo '<div class="alert alert-warning alert-dismissible fade show text-center">
                        <button type="button" class="close" data-dismiss="alert">&times;</button>
                        Thesis class <strong>doesn\'t exist.</strong> Please make it first.
                    </div>';
                return view('auth.register');
            }
        }
        if(User::where('username',$username)->count()>0) {
            echo '<div class="alert alert-warning alert-dismissible fade show text-center">
                    <button type="button" class="close" data-dismiss="alert">&times;</button>
                    This user <strong>already exist.</strong>
                  </div>';
            return view('auth.register');
        } else if(strlen($data['username']) > 18){
            echo '<div class="alert alert-warning alert-dismissible fade show text-center">
                    <button type="button" class="close" data-dismiss="alert">&times;</button>
                    <strong>Username</strong> too long (maximum size: 18 characters).
                  </div>';
            return view('auth.register');
        } else if(strlen($data['phone']) > 18){
            echo '<div class="alert alert-warning alert-dismissible fade show text-center">
                    <button type="button" class="close" data-dismiss="alert">&times;</button>
                    <strong>Invalid</strong> phone number.
                  </div>';
            return view('auth.register');
        } else {
           $user = $this->create($data);
           $role = $data['role'];
           if($role == User::ROLE_DOSEN) {
               Dosen::create(['id'=>$user->id]);
           }else if($role == User::ROLE_MAHASISWA) {
               $id_kelas_tesis = KelasTesis::orderByRaw('updated_at - created_at DESC')->first();
               Mahasiswa::create(['id'=>$user->id, 'id_kelas_tesis'=>$id_kelas_tesis->id]);
           } else if($role == User::ROLE_MANAJER) {
               Manajer::create(['id'=>$user->id]);
           }
            echo '<div class="alert alert-success alert-dismissible fade show text-center">
                    <button type="button" class="close" data-dismiss="alert">&times;</button>
                    <strong>Success !</strong> New user has successfully registered!
                  </div>';
           return view('auth.register');
        }
    }

    public function registerMahasiswaCSV(Request $request) {
        if ($request->hasFile('csv_file')) {
            if ($request->file('csv_file')->getClientOriginalExtension() == 'csv') {
                Excel::import(new MahasiswasImport, $request->file('csv_file'));
                
                $error = \Illuminate\Validation\ValidationException::withMessages([
                   'success' => 'Success ! New user has successfully registered!',
                ]);
                throw $error;
            } else {
                $error = \Illuminate\Validation\ValidationException::withMessages([
                   'type_error' => 'Wrong file type! Please upload the correct file type.',
                ]);
                throw $error;            
            }
        }
    }
}
