<?php

namespace App\Imports;

use App\KelasTesis;
use App\Mahasiswa;
use App\User;
use Illuminate\Validation\Rule;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Maatwebsite\Excel\Concerns\ToCollection;

class MahasiswasImport implements ToCollection
{
    public function collection(Collection $rows)
    {
        $messages = [
            '*.0.required'  => '[Error in :attribute (row.column)] The name is required.',
            '*.1.required'  => '[Error in :attribute (row.column)] The username is required.',
            '*.1.max'       => '[Error in :attribute (row.column)] The maximum length of a username is 18 characters.',
            '*.1.unique'    => '[Error in :attribute (row.column)] The username has already been taken.',
            '*.2.required'  => '[Error in :attribute (row.column)] The email address is required.',
            '*.2.email'     => '[Error in :attribute (row.column)] Invalid email address format.',
            '*.2.unique'    => '[Error in :attribute (row.column)] The email address has already been taken.',
            '*.3.max'       => '[Error in :attribute (row.column)] The maximum length of a phone number is 18 characters.',
            '*.3.regex'     => '[Error in :attribute (row.column)] Invalid phone number format.',
            '*.4.required'  => '[Error in :attribute (row.column)] The password is required.',
        ];

        Validator::make($rows->toArray(), [
            '*.0' => 'required',
            '*.1' => 'required|max:18|unique:users,username',
            '*.2' => 'required|email|unique:users,email',
            '*.3' => ['nullable','max:18','regex:%^[+]?[0-9][0-9]([-]?\s?)[0-9](\s?\d?[-]?)*$%',],
            '*.4' => 'required',
        ],$messages)->validate();

        foreach ($rows as $row) 
        {
            User::create([
                'name'      => $row[0],
                'username'  => $row[1],
                'email'     => $row[2],
                'phone'     => $row[3],
                'password'  => Hash::make($row[4]),
            ]);

            $user = User::where('username',$row[1])->first();
            $id_kelas_tesis = KelasTesis::orderByRaw('updated_at - created_at DESC')->first();
            Mahasiswa::create([
                'id'                => $user->id,
                'id_kelas_tesis'    => $id_kelas_tesis->id,
            ]);
        }
    }
}
